@@ -19,11 +19,11 @@ use function current;
 use function explode;
 use function is_array;
 use function is_int;
-use function is_string;
 use function key;
 use function next;
 use function preg_replace;
 use function reset;
+use function rtrim;
 use function sort;
 use function str_ends_with;
 use function str_starts_with;
@@ -42,11 +42,11 @@ final class Parser
      * @throws RequiredOptionArgumentMissingException
      * @throws UnknownOptionException
      *
-     * @return array{0: list<array{0: non-empty-string, 1: ?non-empty-string}>, 1: list<non-empty-string>}
+     * @return array{0: list<array{0: string, 1: ?string}>, 1: list<string>}
      */
     public function parse(array $argv, string $shortOptions, ?array $longOptions = null): array
     {
-        if (empty($argv)) {
+        if ($argv === []) {
             return [[], []];
         }
 
@@ -111,8 +111,8 @@ final class Parser
     }
 
     /**
-     * @param list<array{0: non-empty-string, 1: ?non-empty-string}> $options
-     * @param list<string>                                           $argv
+     * @param list<array{0: string, 1: ?string}> $options
+     * @param list<string>                       $argv
      *
      * @throws RequiredOptionArgumentMissingException
      */
@@ -142,8 +142,6 @@ final class Parser
                         throw new RequiredOptionArgumentMissingException('-' . $option);
                     }
 
-                    assert(is_string($optionArgument));
-
                     next($argv);
                 }
             }
@@ -153,9 +151,9 @@ final class Parser
     }
 
     /**
-     * @param list<string>                                           $longOptions
-     * @param list<array{0: non-empty-string, 1: ?non-empty-string}> $options
-     * @param list<string>                                           $argv
+     * @param list<string>                       $longOptions
+     * @param list<array{0: string, 1: ?string}> $options
+     * @param list<string>                       $argv
      *
      * @throws AmbiguousOptionException
      * @throws OptionDoesNotAllowArgumentException
@@ -170,6 +168,7 @@ final class Parser
         $optionArgument = null;
 
         if (count($list) > 1) {
+            /** @phpstan-ignore offsetAccess.notFound */
             $optionArgument = $list[1];
         }
 
@@ -184,12 +183,25 @@ final class Parser
 
             $opt_rest = substr($longOption, $optionLength);
 
-            if ($opt_rest !== '' && $i + 1 < $count && $option[0] !== '=' && str_starts_with($longOptions[$i + 1], $option)) {
-                throw new AmbiguousOptionException('--' . $option);
+            if ($opt_rest !== '' &&
+                $i + 1 < $count &&
+                $option[0] !== '=' &&
+                /** @phpstan-ignore offsetAccess.notFound */
+                str_starts_with($longOptions[$i + 1], $option)
+            ) {
+                $candidates = [];
+
+                foreach ($longOptions as $aLongOption) {
+                    if (str_starts_with($aLongOption, $option)) {
+                        $candidates[] = '--' . rtrim($aLongOption, '=');
+                    }
+                }
+
+                throw new AmbiguousOptionException('--' . $option, $candidates);
             }
 
             if (str_ends_with($longOption, '=')) {
-                if (!str_ends_with($longOption, '==') && !strlen((string) $optionArgument)) {
+                if (!str_ends_with($longOption, '==') && (string) $optionArgument === '') {
                     if (false === $optionArgument = current($argv)) {
                         throw new RequiredOptionArgumentMissingException('--' . $option);
                     }
